% Matlab programme written by Hans Røy to fit an exponential function to SRR data, model SRR at the onset, estimate SRB endospore abundance and other parameters as described in the main text (http://dx.doi.org/10.1080/01490451.2016.1190805).

clear all; close all;

GrowthYield    =8.23;   % ng dry biomass per nmol sulfate;
PerCellBiomass  =0.0003; % ng

% Read in the data, define the functions and do a least squares fit
% The function expfit is in a separate file


% time (hours), SRR (nmol/cc/hour)
Amended1=[15.4	0.40
          15.4	0.31	
          19.1	1.65
          19.1	1.96
          21.9	4.88
          21.9	5.82
          26.0	17.31
          26.0	21.90
          28.1	26.03
          28.1	27.33];
      
     

%
Amended2=[48.3	1.81
          48.3	3.99
          52.9	3.24
          52.9	3.23
          65.6	15.15
          65.6	23.09
          72.0	42.67
          72.0	67.22
          76.0	38.51
          76.0	52.34
          88.0	73.70
          88.0	96.30
          92.0	150.06
          92.0	136.98];

Unamended1=[19.3	0.03
            22.1	0.11
            26.2	0.43
            26.2	0.46];

Unamended2=[41.7	0.98
            41.7	1.88
            48.4	1.78
            48.4	1.74
            53.1	2.61
            53.1	2.93
            65.7	9.17
            65.7	11.04
            72.1	13.24
            72.1	24.02
            76.1	28.52
            76.1	28.95];
        


data= Amended2



tmax=ceil(max(data(:,1)));       
       
bestfit=expfit(data); % fit a exponential function to the data
func =  inline('p(1)* p(2).^x','x','p'); % define the exp function for use

figure(1);
hold on;
  line(data(:,1), data(:,2), 'LineStyle', 'none', 'Marker', 'o', 'MarkerSize' , 5, 'MarkerEdgeColor', [0 0 0], 'MarkerFaceColor', [0 0 0]);
  line(data(:,1), func(data(:,1), bestfit), 'Color',[0,0,0]', 'Marker', 'none');
  set(gca,'Yscale','log');
  xlabel('time (hours)');
  ylabel('SRR(nmol cm-3 hour-1)');
  %title(['back extrapolation of SRR']);
hold off;




%Back extrapolate to the first 15 hours           
xxx=[0 : 1 : 15];
SRR=func(xxx, bestfit);
hold on;
  line(xxx,SRR, 'Color',[0,0,0]', 'Marker', 'none');
hold off


% Calculate the SRR at the end of the incubation 
SRRatEnd = func(tmax, bestfit);

% Integrate SRR to the end of the experiment 
SigmaSRR= quad(func,0,tmax, 1.e-6,0,bestfit);    

% Calculate the number of cells produced
biomass = SigmaSRR * GrowthYield; % (nmol/cc) * (ng/nmol) = (ng/cc)
CellsAtEnd=biomass/PerCellBiomass;      % (ng/cc)   / (ng/cell) = (cell/cc)

% Calculate cell specific SRR. We ignore the initial number of cells since
% the population have doubled many times.
CellSpecificSRR= SRRatEnd/CellsAtEnd;

% Now calculate the number of cells during the initial 15 hours from the
% SRR and the cell specific SRR
cells=SRR/CellSpecificSRR;


figure(2);
hold on;
  line(xxx,cells, 'Color',[0,0,0]', 'Marker', 'none');
  %set(gca,'Yscale','log');
  xlabel('time (hours)');
  ylabel('cells per cc');
  %title(['Fit to SRR from the Baltic gas Aarhus Bay transect']);
hold off



%**************************************************************************
%                   Statistical analysis of SRR
%**************************************************************************

bootstat =  bootstrp(10000, @expfit, data); % make a bucket of pseudofits use 100 for test, 10000 for real
Conf_SRR0 =  prctile(bootstat(:,1), [5 50 95]) % print the confidence of SRR0
Conf_k    =  log(prctile(bootstat(:,2), [5 50 95]))% print the confidence of k



% evaluate the SRR at each hour from 1 to tmax   
zzz=[0:tmax];

BootSRR=[];    
for I = 1:length(bootstat),
    BootSRR(I,:)=func(zzz,bootstat(I,:));
end;


ConfSRR=[];
for I = 1:length(zzz),
    ConfSRR(I,:)=prctile(BootSRR(:,I), [5 50 95]);
end;



figure(3);
hold on;
  plot(zzz, ConfSRR)
  line(data(:,1), data(:,2), 'LineStyle', 'none', 'Marker', 'o', 'MarkerSize' , 5, 'MarkerEdgeColor', [0 0 0], 'MarkerFaceColor', [0 0 0]);
  set(gca,'Yscale','log');
  xlabel('time(hours)');
  ylabel('SRR((nmol/cc/hour))');
  title(['Back extrapolation of exponential SRR [0.5 50 95] ']);
hold off



%**************************************************************************
%                   Statistical analysis of cell numbers
%**************************************************************************


% Calculate the SRR at the end of the experiment 
BootSRRatEnd=[];
BootSigmaSRR=[];    
BootBiomass=[];
BootCellsAtEnd=[];
BootCellSpecificSRR=[];
BootCells=[];
for I = 1:length(bootstat),
   % Calculate the SRR at the end of the experiment 
     BootSRRatEnd(I)=func(tmax, bootstat(I,:));
   % Integrate SRR to the end of the experiment 
     BootSigmaSRR(I)=quad(func,0,tmax, 1.e-6,0,bootstat(I,:));
   % Calculate biomass at end of incubation
     BootBiomass(I) = BootSigmaSRR(I) * GrowthYield; % (nmol/cc) * (ng/nmol) = (ng/cc)
   % Calculate number of cells at end  
     BootCellsAtEnd(I)=BootBiomass(I)/PerCellBiomass;      % (ng/cc)   / (ng/cell) = (cell/cc)
   % Calculate cell specific SRR
     BootCellSpecificSRR(I)=BootSRRatEnd(I)/BootCellsAtEnd(I);
   % Calculate the time course of cells for the boot sample
     BootCells(I,:)=BootSRR(I,:)/BootCellSpecificSRR(I);
end;

ConfCells=[];
for I = 1:length(zzz),
    ConfCells(I,:)=prctile(BootCells(:,I), [5 50 95]);
end;

CellsT0 = ConfCells(1,:)
%CellsT40 = ConfCells(41,:)

figure(4);
hold on;
  plot(zzz, ConfCells)
  set(gca,'Yscale','log');
  xlabel('time(hours)');
  ylabel('cells per cc');
  title(['number of active sulfate reducing bacteria [0.5 2.5 5 50 95 97.5 99.5] ']);
hold off


%**************************************************************************
%*********                   Generate output
%**************************************************************************


out=[];
out(:,1)=zzz';
out=[out ConfSRR];
out=[out ConfCells];

% output cell specific SRR with 90% confidence bounds
Conf_csSRR = prctile(BootCellSpecificSRR, [5 50 95])*1000000
% output duplingtime with 90% confidence bounds
Conf_T2= [log(2) log(2) log(2)]./log(prctile(bootstat(:,2), [5 50 95]))